@@ -647,6 +647,44 @@ gda_connection_drop_database (GdaConnection *cnc, const gchar *name)
 	return gda_server_provider_drop_database (cnc->priv->provider_obj, cnc, name);
 }
 
+/**
+ * gda_connection_create_table
+ * @cnc: a #GdaConnection object.
+ * @table_name: name of the table to be created.
+ * @attributes: description of all fields for the new table.
+ *
+ * Creates a table on the given connection from the specified set of fields.
+ *
+ * Returns: %TRUE if successful, %FALSE otherwise.
+ */
+gboolean
+gda_connection_create_table (GdaConnection *cnc, const gchar *table_name, const GdaFieldAttributes *attributes[])
+{
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (table_name != NULL, FALSE);
+	g_return_val_if_fail (attributes != NULL, FALSE);
+
+	return gda_server_provider_create_table (cnc->priv->provider_obj, cnc, table_name, attributes);
+}
+
+/**
+ * gda_connection_drop_table
+ * @cnc: a #GdaConnection object.
+ * @table_name: name of the table to be removed
+ *
+ * Drops a table from the database.
+ *
+ * Returns: %TRUE if successful, %FALSE otherwise.
+ */
+gboolean
+gda_connection_drop_table (GdaConnection *cnc, const gchar *table_name)
+{
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (table_name != NULL, FALSE);
+
+	return gda_server_provider_drop_table (cnc->priv->provider_obj, cnc, table_name);
+}
+
 /**
  * gda_connection_execute_command
  * @cnc: a #GdaConnection object.
@@ -680,6 +718,27 @@ gda_connection_execute_command (GdaConnection *cnc,
 						    cnc, cmd, params);
 }
 
+/**
+ * gda_connection_get_last_insert_id
+ * @cnc: a #GdaConnection object.
+ * @recset: recordset.
+ *
+ * Retrieve from the given #GdaConnection the ID of the last inserted row.
+ * A connection must be specified, and, optionally, a result set. If not NULL,
+ * the underlying provider should try to get the last insert ID for the given result set.
+ *
+ * Returns: a string representing the ID of the last inserted row, or NULL
+ * if an error occurred or no row has been inserted. It is the caller's
+ * reponsibility to free the returned string.
+ */
+gchar *
+gda_connection_get_last_insert_id (GdaConnection *cnc, GdaDataModel *recset)
+{
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+
+	return gda_server_provider_get_last_insert_id (cnc->priv->provider_obj, cnc, recset);
+}
+
 /**
  * gda_connection_execute_single_command
  * @cnc: a #GdaConnection object.
@@ -873,7 +932,8 @@ gda_connection_supports (GdaConnection *cnc, GdaConnectionFeature feature)
  *
  * The list of parameters is specific to each schema type.
  *
- * Returns: a #GdaDataModel containing the data required.
+ * Returns: a #GdaDataModel containing the data required. The caller is responsible
+ * of freeing the returned model.
  */
 GdaDataModel *
 gda_connection_get_schema (GdaConnection *cnc,
