@@ -37,9 +37,9 @@
  * gda_type_to_string
  * @type: Type to convert from.
  *
- * Return the string representing the given #GdaType.
- *
- * Returns: the name of the type.
+ * Returns: the string representing the given #GdaValueType.
+ * This is not necessarily the same string used to describe the column type in a SQL statement.
+ * Use gda_connection_get_schema() with GDA_CONNECTION_SCHEMA_TYPES to get the actual types supported by the provider.
  */
 const gchar *
 gda_type_to_string (GdaValueType type)
@@ -47,6 +47,7 @@ gda_type_to_string (GdaValueType type)
 	switch (type) {
 	case GDA_VALUE_TYPE_NULL : return "null";
 	case GDA_VALUE_TYPE_BIGINT : return "bigint";
+	case GDA_VALUE_TYPE_BIGUINT : return "biguint";
 	case GDA_VALUE_TYPE_BLOB : return "blob";
 	case GDA_VALUE_TYPE_BINARY : return "binary";
 	case GDA_VALUE_TYPE_BOOLEAN : return "boolean";
@@ -54,22 +55,33 @@ gda_type_to_string (GdaValueType type)
 	case GDA_VALUE_TYPE_DOUBLE : return "double";
 	case GDA_VALUE_TYPE_GEOMETRIC_POINT : return "point";
 	case GDA_VALUE_TYPE_INTEGER : return "integer";
+	case GDA_VALUE_TYPE_UINTEGER : return "uinteger";
 	case GDA_VALUE_TYPE_LIST : return "list";
 	case GDA_VALUE_TYPE_NUMERIC : return "numeric";
+	case GDA_VALUE_TYPE_MONEY : return "money"; 
 	case GDA_VALUE_TYPE_SINGLE : return "single";
 	case GDA_VALUE_TYPE_SMALLINT : return "smallint";
+	case GDA_VALUE_TYPE_SMALLUINT : return "smalluint";
 	case GDA_VALUE_TYPE_STRING : return "string";
 	case GDA_VALUE_TYPE_TIME : return "time";
 	case GDA_VALUE_TYPE_TIMESTAMP : return "timestamp";
 	case GDA_VALUE_TYPE_TINYINT : return "tinyint";
-	default:
+	case GDA_VALUE_TYPE_TINYUINT : return "tinyuint";
+    
+	case GDA_VALUE_TYPE_GOBJECT : return "gobject";
+	case GDA_VALUE_TYPE_TYPE : return "type";
+	case GDA_VALUE_TYPE_UNKNOWN : return "unknown";
+	default: ;
 	}
 
-	return "string";
+	return "unknown";
 }
 
 /**
  * gda_type_from_string
+ * @str: the name of a #GdaValueType, as returned by gda_type_to_string().
+ *
+ * Returns: the #GdaValueType represented by the given @str.
  */
 GdaValueType
 gda_type_from_string (const gchar *str)
@@ -78,6 +90,7 @@ gda_type_from_string (const gchar *str)
 
 	if (!g_strcasecmp (str, "null")) return GDA_VALUE_TYPE_NULL;
 	else if (!g_strcasecmp (str, "bigint")) return GDA_VALUE_TYPE_BIGINT;
+	else if (!g_strcasecmp (str, "biguint")) return GDA_VALUE_TYPE_BIGUINT;
 	else if (!g_strcasecmp (str, "binary")) return GDA_VALUE_TYPE_BINARY;
 	else if (!g_strcasecmp (str, "blob")) return GDA_VALUE_TYPE_BLOB;
 	else if (!g_strcasecmp (str, "boolean")) return GDA_VALUE_TYPE_BOOLEAN;
@@ -85,15 +98,23 @@ gda_type_from_string (const gchar *str)
 	else if (!g_strcasecmp (str, "double")) return GDA_VALUE_TYPE_DOUBLE;
 	else if (!g_strcasecmp (str, "point")) return GDA_VALUE_TYPE_GEOMETRIC_POINT;
 	else if (!g_strcasecmp (str, "integer")) return GDA_VALUE_TYPE_INTEGER;
+	else if (!g_strcasecmp (str, "uinteger")) return GDA_VALUE_TYPE_UINTEGER;
 	else if (!g_strcasecmp (str, "list")) return GDA_VALUE_TYPE_LIST;
 	else if (!g_strcasecmp (str, "numeric")) return GDA_VALUE_TYPE_NUMERIC;
+	else if (!g_strcasecmp (str, "money")) return GDA_VALUE_TYPE_MONEY;
 	else if (!g_strcasecmp (str, "single")) return GDA_VALUE_TYPE_SINGLE;
 	else if (!g_strcasecmp (str, "smallint")) return GDA_VALUE_TYPE_SMALLINT;
+	else if (!g_strcasecmp (str, "smalluint")) return GDA_VALUE_TYPE_SMALLUINT;  
 	else if (!g_strcasecmp (str, "string")) return GDA_VALUE_TYPE_STRING;
 	else if (!g_strcasecmp (str, "time")) return GDA_VALUE_TYPE_TIME;
 	else if (!g_strcasecmp (str, "timestamp")) return GDA_VALUE_TYPE_TIMESTAMP;
 	else if (!g_strcasecmp (str, "tinyint")) return GDA_VALUE_TYPE_TINYINT;
-
+	else if (!g_strcasecmp (str, "tinyuint")) return GDA_VALUE_TYPE_TINYUINT;
+  
+	else if (!g_strcasecmp (str, "gobject")) return GDA_VALUE_TYPE_GOBJECT;
+	else if (!g_strcasecmp (str, "type")) return GDA_VALUE_TYPE_TYPE;  
+	else if (!g_strcasecmp (str, "unknown")) return GDA_VALUE_TYPE_UNKNOWN;      
+  
 	return GDA_VALUE_TYPE_UNKNOWN;
 }
 
@@ -108,6 +129,12 @@ add_string_key_to_list (gpointer key, gpointer value, gpointer user_data)
 
 /**
  * gda_string_hash_to_list
+ * @hash_table: a hash table.
+ *
+ * Creates a new list of strings, which contains all keys of a given hash 
+ * table. After using it, you should free this list by calling g_list_free.
+ * 
+ * Returns: a new GList.
  */
 GList *
 gda_string_hash_to_list (GHashTable *hash_table)
@@ -122,21 +149,20 @@ gda_string_hash_to_list (GHashTable *hash_table)
 
 /**
  * gda_sql_replace_placeholders
- * @sql: A SQL command containing placeholders for values.
- * @params: List of values for the placeholders.
+ * @sql: a SQL command containing placeholders for values.
+ * @params: a list of values for the placeholders.
  *
  * Replaces the placeholders (:name) in the given SQL command with
  * the values from the #GdaParameterList specified as the @params
  * argument.
  *
- * Returns: the SQL string with all placeholders replaced, or NULL
+ * Returns: the SQL string with all placeholders replaced, or %NULL
  * on error. On success, the returned string must be freed by the caller
  * when no longer needed.
  */
 gchar *
 gda_sql_replace_placeholders (const gchar *sql, GdaParameterList *params)
 {
-	GString *str;
 	sql_statement *sql_stmt;
 
 	g_return_val_if_fail (sql != NULL, NULL);
@@ -162,7 +188,7 @@ gda_sql_replace_placeholders (const gchar *sql, GdaParameterList *params)
  *
  * It is the caller's responsibility to free the returned value.
  *
- * Returns: the file contents as a newly-allocated string, or NULL
+ * Returns: the file contents as a newly-allocated string, or %NULL
  * if there is an error.
  */
 gchar *
@@ -191,7 +217,7 @@ gda_file_load (const gchar *filename)
  *
  * Saves a chunk of data into a file.
  *
- * Returns: TRUE if successful, FALSE on error.
+ * Returns: %TRUE if successful, %FALSE on error.
  */
 gboolean
 gda_file_save (const gchar *filename, const gchar *buffer, gint len)
@@ -201,7 +227,7 @@ gda_file_save (const gchar *filename, const gchar *buffer, gint len)
 	
 	g_return_val_if_fail (filename != NULL, FALSE);
 
-	fd = open (filename, O_RDWR | O_CREAT, 0644);
+	fd = open (filename, O_RDWR | O_CREAT | O_TRUNC, 0644);
 	if (fd == -1) {
 		gda_log_error (_("Could not create file %s"), filename);
 		return FALSE;
